===========
PCDSWidgets
===========

LCLS PyDM Widget Library

.. toctree::
    :maxdepth: 1
    :caption: Widgets

    vacuum.rst
    icons.rst

.. toctree::
   :maxdepth: 1
   :caption: API Documentation
   :hidden:

   mixins.rst
   utils.rst


.. toctree::
   :maxdepth: 1
   :caption: Developer Documentation
   :hidden:

   dev.rst
   addwidget.rst

.. toctree::
   :maxdepth: 1
   :caption: Related Projects
   :hidden:

   PyDM <https://github.com/slaclab/pydm>

.. toctree::
   :maxdepth: 1
   :caption: Links
   :hidden:

   PCDSWidgets GitHub <https://github.com/pcdshub/pcdswidgets>
   PCDS-wide GitHub <https://github.com/pcdshub>
